REST API
========

Fastr includes a webapp and a REST API. This section contains a listing
of all REST paths. The full documentation is available via swagger with
the paths /swagger.json for the schema or /api/doc/ for the swagger UI.

Quick reference
---------------

.. qrefflask:: fastr.web:app
   :endpoints:
   :include-empty-docstring:
   :order: path

.. autoflask:: fastr.web:app
